Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1728)

Unified Diff: content/renderer/p2p/port_allocator.h

Issue 1309543004: Create a new preference which disables UDP protocol for WebRTC (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/p2p/port_allocator.h
diff --git a/content/renderer/p2p/port_allocator.h b/content/renderer/p2p/port_allocator.h
index 3d1ae5fa161a85cc81d6ea66a3e2f8ea9b1631f2..40bf39ad54e7aaa79450df2f913712001caeb71a 100644
--- a/content/renderer/p2p/port_allocator.h
+++ b/content/renderer/p2p/port_allocator.h
@@ -35,11 +35,11 @@ class P2PPortAllocator : public cricket::BasicPortAllocator {
std::vector<RelayServerConfig> relays;
- // Disable TCP-based transport when set to true.
- bool disable_tcp_transport;
+ // Disable non-proxied UDP-based transport when set to false.
Sergey Ulanov 2015/08/28 15:21:26 What is "non-proxied"? do we ever use proxy for UD
Sergey Ulanov 2015/08/28 15:21:26 nit: reword to avoid double negative: Enables non-
+ bool enable_nonproxied_udp_transport = true;
// Disable binding to individual NICs when set to false.
- bool enable_multiple_routes;
+ bool enable_multiple_routes = true;
};
P2PPortAllocator(P2PSocketDispatcher* socket_dispatcher,

Powered by Google App Engine
This is Rietveld 408576698